/*
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef RSIBREAK_RSITIMER_TEST_H
#define RSIBREAK_RSITIMER_TEST_H

#include <QtTest>

class RSITimerTest: public QObject
{
    Q_OBJECT
    QVector<int> m_intervals;

public:
    RSITimerTest();

private slots:
    void triggerSimpleTinyBreak();
    void triggerComplexTinyBreak();
    void testSuspended();
    void triggerSimpleBigBreak();
    void postponeBreak();
    void screenLock();
    void skipBreak();
    void noPopupBreak();
    void regularBreaks();
};

#endif //RSIBREAK_RSITIMER_TEST_H
